CacheManager class

Cache manager for API responses

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear all cache
get(String key) Future<String?>
Get cached data
getCacheSize() Future<int>
Get cache size
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<void>
Remove cached data
set(String key, String data, CacheConfig config) Future<void>
Set cache data
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CacheManager
no setter